@@ -132,7 +132,7 @@ class NumericPreModelAnalysis:
         self.plot_wordcloud_pvalues(self.cols_sorted_with_pvalue)
         if is_plot:
             if self.n_cols > 50:
-                print("Numerical Pvalues plot")
+                print("Numerical Pvalues plot:")
                 self.plot_histogram_pvalues(self.cols_sorted_with_pvalue)
         print("Pvalues for top numerical features for chi square test:")
         print(pd.DataFrame(self.cols_sorted_with_pvalue[0:top_features], columns=["feature", "pvalue"]))
@@ -255,22 +255,23 @@ class NumericPreModelAnalysis:
             plt.show()
             return None
 
-    def run(self):
+    def run(self, plot=True):
         if self.n_cols > 1:
-            self.analyze_pvalue()
-            if 'classification' in self.data_info.problem_type_val.lower():
+            self.analyze_pvalue(is_plot=plot)
+            if ('classification' in self.data_info.problem_type_val.lower()) and plot:
                 self.partial_plot(classification_row_percent=True)
-                # self.partial_plot(classification_row_percent=False)
+                self.partial_plot(classification_row_percent=False)
             else:
                 self.partial_plot()
             self.tsne()
         elif self.n_cols == 1:
             self.analyze_pvalue()
-            if 'classification' in self.data_info.problem_type_val.lower():
+            if ('classification' in self.data_info.problem_type_val.lower()) and plot:
                 self.partial_plot(classification_row_percent=True)
                 self.partial_plot(classification_row_percent=False)
             else:
-                self.partial_plot()
+                if plot:
+                    self.partial_plot()
         return None
 
 
